@@ -9,7 +9,7 @@ import (
 	"github.com/hofstadter-io/hof/cmd/hof/ga"
 )
 
-var listLong = `print available data models`
+var listLong = `print available datamodels`
 
 func ListRun(args []string) (err error) {
 
@@ -27,17 +27,14 @@ var ListCmd = &cobra.Command{
 		"ls",
 	},
 
-	Short: "print available data models",
+	Short: "print available datamodels",
 
 	Long: listLong,
 
-	PreRun: func(cmd *cobra.Command, args []string) {
+	Run: func(cmd *cobra.Command, args []string) {
 
 		ga.SendCommandPath(cmd.CommandPath())
 
-	},
-
-	Run: func(cmd *cobra.Command, args []string) {
 		var err error
 
 		// Argument Parsing
@@ -58,7 +55,11 @@ func init() {
 
 	ohelp := ListCmd.HelpFunc()
 	ousage := ListCmd.UsageFunc()
+
 	help := func(cmd *cobra.Command, args []string) {
+
+		ga.SendCommandPath(cmd.CommandPath() + " help")
+
 		if extra(cmd) {
 			return
 		}
@@ -72,11 +73,9 @@ func init() {
 	}
 
 	thelp := func(cmd *cobra.Command, args []string) {
-		ga.SendCommandPath(cmd.CommandPath() + " help")
 		help(cmd, args)
 	}
 	tusage := func(cmd *cobra.Command) error {
-		ga.SendCommandPath(cmd.CommandPath() + " usage")
 		return usage(cmd)
 	}
 	ListCmd.SetHelpFunc(thelp)
