@@ -23,17 +23,18 @@ var InfoCmd = &cobra.Command{
 
 	Use: "info",
 
+	Aliases: []string{
+		"status",
+	},
+
 	Short: "get formatter info",
 
 	Long: infoLong,
 
-	PreRun: func(cmd *cobra.Command, args []string) {
+	Run: func(cmd *cobra.Command, args []string) {
 
 		ga.SendCommandPath(cmd.CommandPath())
 
-	},
-
-	Run: func(cmd *cobra.Command, args []string) {
 		var err error
 
 		// Argument Parsing
@@ -62,7 +63,11 @@ func init() {
 
 	ohelp := InfoCmd.HelpFunc()
 	ousage := InfoCmd.UsageFunc()
+
 	help := func(cmd *cobra.Command, args []string) {
+
+		ga.SendCommandPath(cmd.CommandPath() + " help")
+
 		if extra(cmd) {
 			return
 		}
@@ -76,11 +81,9 @@ func init() {
 	}
 
 	thelp := func(cmd *cobra.Command, args []string) {
-		ga.SendCommandPath(cmd.CommandPath() + " help")
 		help(cmd, args)
 	}
 	tusage := func(cmd *cobra.Command) error {
-		ga.SendCommandPath(cmd.CommandPath() + " usage")
 		return usage(cmd)
 	}
 	InfoCmd.SetHelpFunc(thelp)
