@@ -18,7 +18,7 @@ func StartRun(formatter string) (err error) {
 	// you can safely comment this print out
 	// fmt.Println("not implemented")
 
-	err = hfmt.Start(formatter)
+	err = hfmt.Start(formatter, true)
 
 	return err
 }
@@ -31,13 +31,10 @@ var StartCmd = &cobra.Command{
 
 	Long: startLong,
 
-	PreRun: func(cmd *cobra.Command, args []string) {
+	Run: func(cmd *cobra.Command, args []string) {
 
 		ga.SendCommandPath(cmd.CommandPath())
 
-	},
-
-	Run: func(cmd *cobra.Command, args []string) {
 		var err error
 
 		// Argument Parsing
@@ -66,7 +63,11 @@ func init() {
 
 	ohelp := StartCmd.HelpFunc()
 	ousage := StartCmd.UsageFunc()
+
 	help := func(cmd *cobra.Command, args []string) {
+
+		ga.SendCommandPath(cmd.CommandPath() + " help")
+
 		if extra(cmd) {
 			return
 		}
@@ -80,11 +81,9 @@ func init() {
 	}
 
 	thelp := func(cmd *cobra.Command, args []string) {
-		ga.SendCommandPath(cmd.CommandPath() + " help")
 		help(cmd, args)
 	}
 	tusage := func(cmd *cobra.Command) error {
-		ga.SendCommandPath(cmd.CommandPath() + " usage")
 		return usage(cmd)
 	}
 	StartCmd.SetHelpFunc(thelp)
