@@ -8,20 +8,22 @@ import (
 	"github.com/spf13/cobra"
 
 	"github.com/hofstadter-io/hof/cmd/hof/ga"
-
 	"github.com/hofstadter-io/hof/cmd/hof/verinfo"
+	"github.com/hofstadter-io/hof/lib/container"
 )
 
 const versionMessage = `hof - the high code framework
 
-Version:     v%s
+Version:     %s
 Commit:      %s
 
 BuildDate:   %s
 GoVersion:   %s
+CueVersion:  %s
 OS / Arch:   %s %s
 ConfigDir:   %s
 CacheDir:    %s
+Containers:  %s
 
 Author:      Hofstadter, Inc
 Homepage:    https://hofstadter.io
@@ -47,16 +49,28 @@ var VersionCmd = &cobra.Command{
 		configDir, _ := os.UserConfigDir()
 		cacheDir, _ := os.UserCacheDir()
 
+		err := container.InitClient()
+		if err != nil {
+			fmt.Println(err)
+		}
+
+		rt, err := container.GetVersion()
+		if err != nil {
+			fmt.Println(err)
+		}
+
 		fmt.Printf(
 			versionMessage,
 			verinfo.Version,
 			verinfo.Commit,
 			verinfo.BuildDate,
 			verinfo.GoVersion,
+			verinfo.CueVersion,
 			verinfo.BuildOS,
 			verinfo.BuildArch,
 			filepath.Join(configDir,"hof"),
 			filepath.Join(cacheDir,"hof"),
+			rt,
 		)
 	},
 }
