@@ -16,7 +16,8 @@ import (
 
 type File struct {
 	// Input Data, local to this file
-	In interface{}
+	// this can sometimes be a list for Adhoc
+	In any
 
 	// The full path under the output location
 	// empty implies don't generate, even though it may endup in the list
@@ -33,7 +34,22 @@ type File struct {
 	FormattingConfig   *FmtConfig
 
 	// Template delimiters
-	TemplateDelims *templates.Delims
+	TemplateDelims templates.Delims
+
+	// CUE settings
+	Package        string
+	Raw            bool
+	Final          bool
+	Concrete       bool
+	Definitions    bool
+	Optional       bool 
+	Hidden         bool 
+	Attributes     bool
+	Docs           bool 
+	InlineImports  bool 
+	ErrorsAsValues bool
+
+
 
 	//
 	// Hof internal usage
@@ -44,8 +60,8 @@ type File struct {
 	Value cue.Value
 
 	// Template Instance Pointer
-	//   If local, this will be created when the template content is laoded
-	//   If a named template, acutal template lives in the generator and is created at folder import time
+	//   If local, this will be created when the template content is loaded
+	//   If a named template, actual template lives in the generator and is created at folder import time
 	TemplateInstance *templates.Template
 
 	// Content
@@ -64,8 +80,28 @@ type File struct {
 	parent *Generator
 }
 
+func (F *File) MergeIn(other map[string]any) {
+	// merge with other if map / struct
+	// (this is probably always the case (should be enforced?))
+	switch fin := F.In.(type) {
+	case map[string]any:
+		for k, v := range other {
+			// only copy in top-level elements which do not exist already
+			if _, ok := fin[k]; !ok {
+				fin[k] = v
+			}
+		}
+		F.In = fin
+	}
+}
+
 func (F *File) Render(outdir string, UseDiff3, NoFmt bool) error {
 	// fmt.Println("F.Render:", F.Filepath, UseDiff3)
+
+	if F.Filepath == "" {
+		return fmt.Errorf("trying to render a file with no filepath")
+	}
+
 	var err error
 	F.RenderContent = bytes.TrimSpace(F.RenderContent)
 
@@ -197,7 +233,7 @@ func (F *File) diff3() (write bool, err error) {
 	O := bytes.NewReader(SF)
 	B := bytes.NewReader(FC)
 	labelB := "Code Gen"
-	detailed := false
+	detailed := true
 
 	result, err := diff3.Merge(A, O, B, detailed, labelA, labelB)
 	if err != nil {
@@ -205,6 +241,9 @@ func (F *File) diff3() (write bool, err error) {
 		return false, err
 	}
 
+	// TODO, filter results which have an empty "Your File" content
+	// (will this break other legit cases?)
+
 	merged, err := ioutil.ReadAll(result.Result)
 	if err != nil {
 		F.IsErr = 1
@@ -257,7 +296,7 @@ func (F *File) diff2() (write bool, err error) {
 }
 
 func (F *File) RenderData() (err error) {
-	F.RenderContent, err = formatData(F.Value, F.DatafileFormat)
+	F.RenderContent, err = F.formatData(F.Value, F.DatafileFormat)
 	if err != nil {
 		F.Errors = append(F.Errors, err)
 		return err
