@@ -4,43 +4,25 @@ import (
 	"bytes"
 	"encoding/json"
 	"fmt"
-	"os"
 
 	"cuelang.org/go/cue"
+	"cuelang.org/go/cue/ast"
 	"cuelang.org/go/cue/format"
 	"cuelang.org/go/encoding/yaml"
 	"github.com/clbanning/mxj"
-	"github.com/naoina/toml"
+	"github.com/BurntSushi/toml"
 
 	hfmt "github.com/hofstadter-io/hof/lib/fmt"
 )
 
-var FORMAT_DISABLED = false
-
-func init() {
-	val := os.Getenv("HOF_FORMAT_DISABLED")
-	if val == "true" || val == "1" {
-		FORMAT_DISABLED=true
-	}
-	
-	// gracefully init images / containers
-	err := hfmt.GracefulInit()
-	if err != nil {
-		FORMAT_DISABLED=true
-	}
-}
-
 type FmtConfig struct {
 	Formatter string
 	Config    interface{}
 }
 
 func (F *File) FormatRendered() (err error) {
-	// should we format? (has it been disabled anywhere)
-	if !(FORMAT_DISABLED || F.FormattingDisabled) {
-		// inspect file settings to see if there is fmtr config...
-		// try using hof/fmt containers, this is auto inference
 
+	if !F.FormattingDisabled {
 		// current content
 		fmtd := F.RenderContent
 
@@ -68,10 +50,10 @@ func (F *File) FormatRendered() (err error) {
 	return nil
 }
 
-func formatData(val cue.Value, format string) ([]byte, error) {
+func (F *File) formatData(val cue.Value, format string) ([]byte, error) {
 	switch format {
 	case "cue":
-		return formatCue(val)
+		return F.formatCue(val)
 
 	case "json":
 		return formatJson(val)
@@ -90,16 +72,56 @@ func formatData(val cue.Value, format string) ([]byte, error) {
 	}
 }
 
-func formatCue(val cue.Value) ([]byte, error) {
+func (F *File) formatCue(val cue.Value) ([]byte, error) {
 
-	syn := val.Syntax(
-		cue.Final(),
-		cue.Definitions(true),
-		cue.Hidden(true),
-		cue.Optional(true),
-		cue.Attributes(true),
-		cue.Docs(true),
-	)
+	// v := val
+
+	opts := []cue.Option{
+		cue.Concrete(F.Concrete),
+		cue.Definitions(F.Definitions),
+		cue.Optional(F.Optional),
+		cue.Hidden(F.Hidden),
+		cue.Attributes(F.Attributes),
+		cue.Docs(F.Docs),
+		// cue.InlineImports(F.InlineImports),
+		cue.ErrorsAsValues(F.ErrorsAsValues),
+	}
+	if F.Final {
+		opts = append(opts, cue.Final())
+	}
+	if F.Raw {
+		opts = append(opts, cue.Raw())
+	}
+
+	syn := val.Syntax(opts...)
+
+	// fmt.Printf("%# v\n", syn)
+
+	//
+	if F.Package != "" {
+		pkgDecl := &ast.Package {
+			Name: ast.NewIdent(F.Package),
+		}
+		decls := []ast.Decl{pkgDecl}
+		// this could cause an issue?
+		switch t := syn.(type) {
+		case *ast.File:
+			t.Decls = append(decls, t.Decls...)
+
+		case *ast.StructLit:
+			decls = append(decls, t.Elts...)
+			f := &ast.File{
+				Decls: decls,
+			}
+			syn = f
+		case *ast.ListLit:
+			decls = append(decls, t)
+			f := &ast.File{
+				Decls: decls,
+			}
+			syn = f
+		}
+	}
 
 	bs, err := format.Node(syn)
 	if err != nil {
@@ -137,11 +159,12 @@ func formatToml(val cue.Value) ([]byte, error) {
 		return nil, err
 	}
 
-	bs, err := toml.Marshal(v)
+	buf := new(bytes.Buffer)
+	err = toml.NewEncoder(buf).Encode(v)
 	if err != nil {
 		return nil, err
 	}
-	return bs, nil
+	return buf.Bytes(), nil
 }
 
 func formatXml(val cue.Value) ([]byte, error) {
