@@ -9,6 +9,7 @@ import (
 	"cuelang.org/go/cue"
 	"github.com/mattn/go-zglob"
 
+	"github.com/hofstadter-io/hof/lib/hof"
 	"github.com/hofstadter-io/hof/lib/templates"
 )
 
@@ -20,7 +21,8 @@ type TemplateGlobs struct {
 	// Prefix to trim
 	TrimPrefix string
 	// Custom delims
-	Delims *templates.Delims
+	Delims templates.Delims
+	DelimGlobs map[string]templates.Delims
 }
 
 type StaticGlobs struct {
@@ -34,11 +36,12 @@ type StaticGlobs struct {
 
 type TemplateContent struct {
 	Content string
-	Delims  *templates.Delims
+	Delims  templates.Delims
 }
 
 // A generator pulled from the cue instances
 type Generator struct {
+	*hof.Node[Generator]
 	//
 	// Set by Hof via cuelang extraction
 	// Label in Cuelang
@@ -50,11 +53,10 @@ type Generator struct {
 	// Other important dirs when loading templates (auto set)
 	CueModuleRoot string
 	WorkingDir    string
-	rootToCwd     string  // module root -> working dir (foo/bar)
-	cwdToRoot     string  // module root <- working dir (../..)
+	CwdToRoot     string  // module root <- working dir (../..)
 
 	// "Global" input, merged with out replacing onto the files
-	In  map[string]interface{}
+	In  map[string]any
 	Val cue.Value
 
 	// File globs to watch and trigger regen on change
@@ -93,9 +95,9 @@ type Generator struct {
 
 	// backpointers, if a subgen
 	parent  *Generator
-	runtime *Runtime
 
 	// Used for indexing into the vendor directory...
+	// TODO, rename this ModuleName
 	PackageName string
 
 	// Use Diff3 & Shadow
@@ -122,7 +124,7 @@ type Generator struct {
 
 	// Print extra information
 	Debug bool
-	verbosity int
+	Verbosity int
 
 	// Status for this generator and processing
 	Stats *GeneratorStats
@@ -131,22 +133,15 @@ type Generator struct {
 	CueValue cue.Value
 }
 
-func NewGenerator(label string, value cue.Value, R *Runtime) *Generator {
+func NewGenerator(node *hof.Node[Generator]) *Generator {
 	// TODO, only transfer what is needed
 
 	return &Generator{
-		// runtime copyin
-		runtime:       R,
-		CueModuleRoot: R.CueModuleRoot,
-		WorkingDir:    R.WorkingDir,
-		cwdToRoot:     R.cwdToRoot,
-		rootToCwd:     R.rootToCwd,
-		UseDiff3:      R.Flagpole.Diff3,
-		NoFormat:      R.Flagpole.NoFormat,
+		Node: node,
 
 		// generator specific vals
-		Name:          label,
-		CueValue:      value,
+		Name:          node.Hof.Label,
+		CueValue:      node.Value,
 
 		// initialize containers
 		PartialsMap:   templates.NewTemplateMap(),
@@ -192,8 +187,8 @@ func (G *Generator) ShadowPath() string {
 
 func (G *Generator) Initialize() []error {
 	var errs []error
-	if G.verbosity > 1 {
-		fmt.Println("initialzing:", G.NamePath())
+	if G.Verbosity > 1 {
+		fmt.Println("initializing:", G.NamePath())
 	}
 
 	// zero, read static files
@@ -223,31 +218,59 @@ func (G *Generator) Initialize() []error {
 	return errs
 }
 
+/* TODO, that the order of embedded vs disk files is inconsistent, we should clean this up and ensure consistent semantics (which may be the case?)
+	- statics: disk -> embed
+	- partials: embed -> disk
+	- templates: embed -> disk
+*/
+
 func (G *Generator) initStaticFiles() []error {
 	var errs []error
 
+	// baseDir should always be an absolute path
+	baseDir := G.CueModuleRoot
+	// lookup in vendor directory, this will need to change once CUE uses a shared cache in the user homedir
+	if G.PackageName != "" {
+		baseDir = filepath.Join(G.CueModuleRoot, CUE_VENDOR_DIR, G.PackageName)
+	}
+
 	// Start with static file globs
 	for _, Static := range G.Statics {
+
+		prefix := filepath.Clean(Static.TrimPrefix)
+
+		// we need to check if the base directory exists, becuase we have defaults in the schema
+		fullTrimDir := filepath.Join(baseDir, prefix)
+		_, err := os.Stat(fullTrimDir)
+		if err != nil {
+			fmt.Printf("warning: from %s, directory %s not found, for gen %s:%s, if you do not intend to use static files, set 'Statics: []'\n", baseDir, prefix, G.PackageName, G.Hof.Path)
+			continue
+		}
+
 		for _, Glob := range Static.Globs {
-			bdir := G.CueModuleRoot
-			// lookup in vendor directory, this will need to change once CUE uses a shared cache in the user homedir
-			if G.PackageName != "" {
-				bdir = filepath.Join(G.CueModuleRoot, CUE_VENDOR_DIR, G.PackageName)
-			}
+			fullGlobDir := filepath.Join(baseDir, Glob)
 
 			// get list of static files
-			matches, err := zglob.Glob(filepath.Join(bdir, Glob))
+			matches, err := zglob.Glob(fullGlobDir)
 			if err != nil {
-				err = fmt.Errorf("while globbing %s / %s\n%w\n", bdir, Glob, err)
+				err = fmt.Errorf("while globbing %s / %s\n%w\n", baseDir, Glob, err)
 				errs = append(errs, err)
 				return errs
 			}
-			if G.verbosity > 1 {
-				fmt.Printf("%s:%s:%s has %d static matches\n", G.NamePath(), bdir, Glob, len(matches))
+			if G.Verbosity > 1 {
+				fmt.Printf("%s:%s:%s has %d static matches\n", G.NamePath(), baseDir, Glob, len(matches))
 			}
 
 			// for each static file, calc some dirs and write output & shadow
 			for _, match := range matches {
+				info, err := os.Stat(match)
+				if err != nil {
+					fmt.Printf("warning: error while loading statics %s: %s\n", match, err)
+					continue
+				}
+				if info.IsDir() {
+					continue
+				}
 				// read the file
 				content, err := os.ReadFile(match)
 				if err != nil {
@@ -256,13 +279,13 @@ func (G *Generator) initStaticFiles() []error {
 				}
 
 				// remove and add prefixes, per the configuration
-				mo := strings.TrimPrefix(match, filepath.Join(bdir, Static.TrimPrefix))
+				mo := strings.TrimPrefix(match, fullTrimDir)
 				// because Join removes?
 				mo = strings.TrimPrefix(mo, "/")
 				fp := filepath.Join(Static.OutPrefix, mo)
 
-				if G.verbosity > 2 {
-					fmt.Println("static FN:", match, filepath.Join(bdir, Static.TrimPrefix), mo)
+				if G.Verbosity > 2 {
+					fmt.Println("static FN:", match, fullTrimDir, mo)
 					fmt.Println("    ", fp, filepath.Clean(fp))
 				}
 
@@ -271,6 +294,7 @@ func (G *Generator) initStaticFiles() []error {
 					Filepath:     filepath.Clean(fp),
 					RenderContent: []byte(content),
 					StaticFile:   true,
+					parent: G,
 				}
 
 				// check for collisions
@@ -279,7 +303,7 @@ func (G *Generator) initStaticFiles() []error {
 					continue
 				}
 
-				if G.verbosity > 1 {
+				if G.Verbosity > 1 {
 					fmt.Printf(" +s %s:%s\n", G.NamePath(), F.Filepath)
 				}
 
@@ -295,6 +319,7 @@ func (G *Generator) initStaticFiles() []error {
 			Filepath:     filepath.Clean(p),
 			RenderContent: []byte(content),
 			StaticFile:   true,
+			parent: G,
 		}
 
 		// check for collisions
@@ -303,7 +328,7 @@ func (G *Generator) initStaticFiles() []error {
 			continue
 		}
 
-		if G.verbosity > 1 {
+		if G.Verbosity > 1 {
 			fmt.Printf(" +s %s:%s\n", G.NamePath(), F.Filepath)
 		}
 
@@ -329,7 +354,7 @@ func (G *Generator) initPartials() []error {
 		// check for collisions
 		_, ok := G.PartialsMap[path]
 		if !ok {
-			if G.verbosity > 1 {
+			if G.Verbosity > 1 {
 				fmt.Printf(" +p %s:%s\n", G.NamePath(), path)
 			}
 			// TODO, do we also want to namespace with the template module name?
@@ -339,28 +364,39 @@ func (G *Generator) initPartials() []error {
 		}
 	}
 
+	// baseDir should always be an absolute path
+	baseDir := G.CueModuleRoot
+	// lookup in vendor directory, this will need to change once CUE uses a shared cache in the user homedir
+	if G.PackageName != "" {
+		baseDir = filepath.Join(G.CueModuleRoot, CUE_VENDOR_DIR, G.PackageName)
+	}
+
 	// then partials from disk via globs
 	for _, tg := range G.Partials {
+		prefix := filepath.Clean(tg.TrimPrefix)
+
+		// we need to check if the base directory exists, becuase we have defaults in the schema
+		fullTrimDir := filepath.Join(baseDir, prefix)
+		_, err := os.Stat(fullTrimDir)
+		if err != nil {
+			fmt.Printf("warning: from %s, directory %s not found, for gen %s:%s, if you do not intend to use partials files, set 'Partials: []'\n", baseDir, prefix, G.PackageName, G.Hof.Path)
+			continue
+		}
+
+
 		for _, glob := range tg.Globs {
 			// setup vars
-			prefix := filepath.Clean(tg.TrimPrefix)
 			glob = filepath.Clean(glob)
-
-			if !strings.HasPrefix(glob, "/") {
-
-				if G.PackageName != "" {
-					glob = filepath.Join(CUE_VENDOR_DIR, G.PackageName, glob)
-					prefix = filepath.Join(CUE_VENDOR_DIR, G.PackageName, prefix)
-				}
-
-				// this is how we deal with running generators in the same module
-				// they are defined in, while keeping the path spec for them simple
-				glob = filepath.Join(G.cwdToRoot, glob)
-				prefix = filepath.Join(G.cwdToRoot, prefix)
+			glob = filepath.Join(baseDir, glob)
+			delimMap := make(map[string]templates.Delims)
+			for g,d := range tg.DelimGlobs {
+				g = filepath.Clean(g)
+				g = filepath.Join(baseDir, g)
+				delimMap[g] = d
 			}
 
-			pMap, err := templates.CreateTemplateMapFromFolder(glob, prefix, tg.Delims)
-			if G.verbosity > 1 {
+			pMap, err := templates.CreateTemplateMapFromFolder(glob, fullTrimDir, tg.Delims, delimMap)
+			if G.Verbosity > 1 {
 				fmt.Printf("%s:%s has %d partial matches\n", G.NamePath(), glob, len(pMap))
 			}
 
@@ -372,7 +408,7 @@ func (G *Generator) initPartials() []error {
 			for k, T := range pMap {
 				_, ok := G.PartialsMap[k]
 				if !ok {
-					if G.verbosity > 1 {
+					if G.Verbosity > 1 {
 						fmt.Printf(" +p %s:%s\n", G.NamePath(), k)
 					}
 					// TODO, do we also want to namespace with the template module name?
@@ -404,7 +440,7 @@ func (G *Generator) initTemplates() []error {
 
 		_, ok := G.TemplateMap[path]
 		if !ok {
-			if G.verbosity > 1 {
+			if G.Verbosity > 1 {
 				fmt.Printf(" +t %s:%s\n", G.NamePath(), path)
 			}
 
@@ -415,28 +451,37 @@ func (G *Generator) initTemplates() []error {
 		}
 	}
 
+	// baseDir should always be an absolute path
+	baseDir := G.CueModuleRoot
+	// lookup in vendor directory, this will need to change once CUE uses a shared cache in the user homedir
+	if G.PackageName != "" {
+		baseDir = filepath.Join(G.CueModuleRoot, CUE_VENDOR_DIR, G.PackageName)
+	}
+
 	for _, tg := range G.Templates {
+		prefix := filepath.Clean(tg.TrimPrefix)
+
+		// we need to check if the base directory exists, becuase we have defaults in the schema
+		fullTrimDir := filepath.Join(baseDir, prefix)
+		_, err := os.Stat(fullTrimDir)
+		if err != nil {
+			fmt.Printf("warning: from %s, directory %s not found, for gen %s:%s, if you do not intend to use templates files, set 'Templates: []'\n", baseDir, prefix, G.PackageName, G.Hof.Path)
+			continue
+		}
+
 		for _, glob := range tg.Globs {
 			// setup vars
 			glob = filepath.Clean(glob)
-			prefix := filepath.Clean(tg.TrimPrefix)
-
-			// if not an absolute path
-			if !strings.HasPrefix(glob, "/") {
-				if G.PackageName != "" {
-					glob = filepath.Join(CUE_VENDOR_DIR, G.PackageName, glob)
-					prefix = filepath.Join(CUE_VENDOR_DIR, G.PackageName, prefix)
-				}
-
-				// this is how we deal with running generators in the same module
-				// they are defined in, while keeping the path spec for them simple
-				// note, these will be no-ops when there is no cue.mod
-				glob = filepath.Join(G.cwdToRoot, glob)
-				prefix = filepath.Join(G.cwdToRoot, prefix)
+			glob = filepath.Join(baseDir, glob)
+			delimMap := make(map[string]templates.Delims)
+			for g,d := range tg.DelimGlobs {
+				g = filepath.Clean(g)
+				g = filepath.Join(baseDir, g)
+				delimMap[g] = d
 			}
 
-			pMap, err := templates.CreateTemplateMapFromFolder(glob, prefix, tg.Delims)
-			if G.verbosity > 1 {
+			pMap, err := templates.CreateTemplateMapFromFolder(glob, fullTrimDir, tg.Delims, delimMap)
+			if G.Verbosity > 1 {
 				fmt.Printf("%s:%s has %d template matches\n", G.NamePath(), glob, len(pMap))
 			}
 
@@ -448,7 +493,7 @@ func (G *Generator) initTemplates() []error {
 			for k, T := range pMap {
 				_, ok := G.TemplateMap[k]
 				if !ok {
-					if G.verbosity > 1 {
+					if G.Verbosity > 1 {
 						fmt.Printf(" +t %s:%s\n", G.NamePath(), k)
 					}
 
@@ -473,9 +518,11 @@ func (G *Generator) initFileGens() []error {
 	var errs []error
 
 	for _, F := range G.Out {
+		F.parent = G
+
 		// support text/template in output file path
 		if strings.Contains(F.Filepath, "{{") {
-			ft, err := templates.CreateFromString("filepath", F.Filepath, nil)
+			ft, err := templates.CreateFromString("filepath", F.Filepath, templates.Delims{})
 			if err != nil {
 				errs = append(errs, err)
 			}
@@ -490,17 +537,20 @@ func (G *Generator) initFileGens() []error {
 
 		// check for collisions
 		if old,ok := G.Files[F.Filepath]; ok {
-			fmt.Printf("WARN: duplicate generated file %q in %q & %q\n", F.Filepath, G.NamePath(), old.parent.NamePath())
+			static := ""
+			if old.StaticFile {
+				static = " (static)"
+			}
+			
+			fmt.Printf("WARN: duplicate generated file %q in %q & %q%s\n", F.Filepath, G.NamePath(), old.parent.NamePath(), static)
 			// errs = append(errs, fmt.Errorf("duplicate generated file %q in %q", F.Filepath, G.NamePath()))
 			continue
 		}
 
-		if G.verbosity > 1 {
+		if G.Verbosity > 1 {
 			fmt.Printf(" +f %s:%s\n", G.NamePath(), F.Filepath)
 		}
 
-		F.parent = G
-
 		G.Files[F.Filepath] = F
 		G.OrderedFiles = append(G.OrderedFiles, F)
 	}
@@ -563,11 +613,10 @@ func (G *Generator) registerPartials(T *templates.Template) error {
 
 	for k, P := range G.PartialsMap {
 		t := T.T.New(k)
-
-		// todo, do we need to do this twice?, has it already been done?
-		// maybe? because of how text/template contexts work
-		templates.AddGolangHelpers(t)
-		t.Parse(P.Source)
+		_, err := t.Parse(P.Source)
+		if err != nil {
+			return err
+		}
 	}
 
 	return nil
