@@ -18,7 +18,9 @@ import (
 // It returns the script content section of the txtar archive.
 func (ts *Script) setupTest() string {
 	ts.workdir = filepath.Join(ts.testTempDir, "script-"+ts.name)
-	ts.Check(os.MkdirAll(filepath.Join(ts.workdir, "tmp"), 0777))
+
+	ts.resetDirs()
+
 	env := &Env{
 		Vars: []string{
 			"WORK=" + ts.workdir, // must be first for ts.abbrev
@@ -39,6 +41,12 @@ func (ts *Script) setupTest() string {
 	return ts.setupFromEnv(env)
 }
 
+func (ts *Script) resetDirs() {
+	ts.Check(os.RemoveAll(ts.workdir))
+	ts.Check(os.MkdirAll(ts.workdir, 0777))
+	return
+}
+
 // setupRun sets up the script execution for working in the current directory.
 // the current environment will be exposed to the script
 // It returns the script content section of the txtar archive.
